@@ -6,8 +6,10 @@ use std::path::Path;
 
 #[derive(Serialize, Deserialize, Debug)]
 pub struct GistFile {
-    #[serde(skip_serializing, default = "GistFile::default_name")] pub name: String,
-    #[serde(rename(serialize = "content"))] pub content: String,
+    #[serde(skip_serializing, default = "GistFile::default_name")]
+    pub name: String,
+    #[serde(rename(serialize = "content"))]
+    pub content: String,
 }
 
 impl GistFile {
